pub struct InstanceError {
pub(crate) message: String,
pub(crate) source: Option<Arc<dyn Error + Send + Sync + 'static>>,
}Expand description
Error occurring while trying to create an instance, or create a surface from an instance; typically relating to the state of the underlying graphics API or hardware.
Fields
message: StringThese errors are very platform specific, so do not attempt to encode them as an enum.
This message should describe the problem in sufficient detail to be useful for a user-to-developer “why won’t this work on my machine” bug report, and otherwise follow https://rust-lang.github.io/api-guidelines/interoperability.html#error-types-are-meaningful-and-well-behaved-c-good-err.
source: Option<Arc<dyn Error + Send + Sync + 'static>>Underlying error value, if any is available.
Implementations